==> slapos.cookbook-0.1.tar.gz: slapos.cookbook-0.1/slapos/recipe/template.py <==
##############################################################################
#
# Copyright (c) 2010 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import collective.recipe.template
import zc.buildout
class Recipe(collective.recipe.template.Recipe):
  def __init__(self, buildout, name, options):
    download = zc.buildout.download.Download(buildout['buildout'],
                hash_name=True)
    path, is_temp = download(options.pop('url'),
        md5sum=options.get('md5sum'))
    options['input'] = path
    collective.recipe.template.Recipe.__init__(self, buildout, name, options)

==> slapos.cookbook-0.63.tar.gz: slapos.cookbook-0.63/slapos/recipe/template.py <==
##############################################################################
#
# Copyright (c) 2010 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
import os

from slapos.recipe.librecipe import GenericBaseRecipe

class Recipe(GenericBaseRecipe):

    def install(self):
        mapping = self.options.copy()
        for key in ('output', 'template', 'recipe', 'mode'):
            if key in mapping:
                del mapping[key]

        with open(self.options['output'], 'w') as output, \
             open(self.options['template'], 'r') as template:
            output.write(template.read() % mapping)

        if 'mode' in self.options:
            os.chmod(self.options['output'], int(self.options['mode'], 8))

        return [self.options['output'], ]
